@@ -26,7 +26,7 @@ describe 'manila::share::glusterfs' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({ :fqdn => 'some.host.tld'}))
+        facts.merge!(OSDefaults.get_facts())
       end
       it_behaves_like 'glusterfs share driver'
     end
